@@ -61,7 +61,7 @@ class ImportCellParser:
         :return: normalized task owners' names in a list() parsed from the cell
         """
         _value = cellobject.value
-        # Trim and split by semicolons
+        # Trim and split by separators
         _value_raw_list = _value.strip().split(sep)
         # Normalize each item and filter out empty ones, fill filtered list
         _value_users_list = list()
@@ -71,6 +71,25 @@ class ImportCellParser:
                 _value_users_list.append(chr(0x0020).join(strnorm(_trimmed_item)))
         return _value_users_list if _value_users_list else None
 
+    def _parse_spaces_list(self, cellobject: openpyxl.cell.cell.Cell, sep: str) -> Union[List[str], None]:
+        """
+        Parse list of space names from cell value, use given separator string
+
+        :param cellobject: openpyxl cell object to parse
+        :param sep: string to use as separator for str.split()
+        :return: normalized task spaces' names in a list() parsed from the cell
+        """
+        _value = cellobject.value
+        # Trim and split by separators
+        _value_raw_list = _value.strip().split(sep)
+        # Normalize each item and filter out empty ones, fill filtered list
+        _value_spaces_list = list()
+        for _item in _value_raw_list:
+            _trimmed_item = _item.strip()
+            if _trimmed_item:
+                _value_spaces_list.append(chr(0x0020).join(strnorm(_trimmed_item)))
+        return _value_spaces_list if _value_spaces_list else None
+
     def _parseyesno(self, cellobject: openpyxl.cell.cell.Cell) -> Union[bool, None]:
         """
         Parse "yes" / "no" type of values, it stringifies, trims, uppercases and matches with "yes" in
@@ -523,3 +542,43 @@ class ImportCellParser:
             raise ImportCellParserException((f"IQF023LANGUAGE: Language not supported by "
                                              f"parser: {_value_stripped_lower}"))
         return _value_stripped_lower
+
+    def IQF024NFCSPACESBEGIN(self, cellobject: openpyxl.cell.cell.Cell) -> Union[List[str], None]:
+        """
+        Space list used to detect begin cleaning of the room by NFC linked to the space.
+
+        Parse list of spaces from cell value, return list of normalized names of spaces with strnorm(). In the
+        MS Excel sheet cell value space names must be separated with ; (semicolon) symbol, empty values between
+        separators will be just ignored.
+
+        :param cellobject: openpyxl cell object to parse
+        :return: normalized spaces' names in a list() parsed from the cell
+        """
+        if not isinstance(cellobject, Cell):
+            raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
+        if cellobject.value is None:
+            return None
+        if not isinstance(cellobject.value, str):
+            raise ImportCellParserException((f"IQF024NFCSPACESBEGIN: Cell contents type is {type(cellobject.value)}, "
+                                             f"string type required"))
+        return self._parse_spaces_list(cellobject, ";")
+
+    def IQF025NFCSPACESDONE(self, cellobject: openpyxl.cell.cell.Cell) -> Union[List[str], None]:
+        """
+        Space list used to detect done cleaning of the room by NFC linked to the space.
+
+        Parse list of spaces from cell value, return list of normalized names of spaces with strnorm(). In the
+        MS Excel sheet cell value space names must be separated with ; (semicolon) symbol, empty values between
+        separators will be just ignored.
+
+        :param cellobject: openpyxl cell object to parse
+        :return: normalized spaces' names in a list() parsed from the cell
+        """
+        if not isinstance(cellobject, Cell):
+            raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
+        if cellobject.value is None:
+            return None
+        if not isinstance(cellobject.value, str):
+            raise ImportCellParserException((f"IQF025NFCSPACESDONE: Cell contents type is {type(cellobject.value)}, "
+                                             f"string type required"))
+        return self._parse_spaces_list(cellobject, ";")
